# AIRPrediction
(Framework) AIR Quality Forecast Model leveraging Time Series Models to enable timely preventive measures to reduce harmful impact on U.S. citizens.

## Dataset to Train the Time Series Model AIR.Prototype_ver.1
Include this cvs file in the package: 
https://www.kaggle.com/sogun3/uspollution
pollution_us_2000_2016.csv(382.37 MB)

## Package Name for PIP Installation
pip install AIRPrediction

## Executable Command

## Command to Run Sample App
1. Install all the requirements by doing "pip3 install -r requirements.txt"
2. Run the flask app by "python3 forecast-flask-app.py"
3. The URL will appear: http://127.0.0.1:5000/
4. Copy and paste the URL in your browser
5. (For Prototype purpose) Enter exactly Pollutants: CO States: Washington Select Date: 2021, 07, 27 
6. The model will start training in your command prompt
7. After waiting about five minutes
8. Predicted value will appear on the webpage

## Repository Link
https://github.com/Data-for-Good-by-UF/AIR

## Sample Application
The following files belong to the Sample Application:
  sampleapp.py
